@@ -1,6 +1,6 @@
 #  Board and related client
 
-
+from os import environ
 from typing import Optional, List
 from pydantic import BaseModel, Field
 from pydantic import condecimal
@@ -12,6 +12,38 @@ from .artifact_source import ArtifactSource
 from ..user import Team, authenticated_user, all_teams
 
 
+###
+##   EvaluationResult
+###
+
+class EvaluationResult(BaseModel):
+    """
+    One (name: value) evaluation result pair for a particular evaluation.
+    Value can be an integer, float, bool, or string.
+    """
+    id:       int             = Field(description='Unique result ID')
+    eval_id:  int             = Field(description='The evaluation with which this result is associated')
+    name:     str             = Field(description='The name of this result')
+    intval:   Optional[int]   = Field(description='an integer evaluation result')
+    floatval: Optional[float] = Field(description='a double float evaluation result')
+    strval:   Optional[str]   = Field(description='a string evaluation result')
+    boolval:  Optional[bool]  = Field(description='a boolean evaluation result')
+
+
+
+
+class PostEvaluationResult(BaseModel):
+    """
+    One (name: value) evaluation result pair for a particular evaluation.
+    Value can be an integer, float, bool, or string.
+    """
+    name:     str             = Field(description='The name of this result')
+    intval:   Optional[int]   = Field(description='an integer evaluation result')
+    floatval: Optional[float] = Field(description='a double float evaluation result')
+    strval:   Optional[str]   = Field(description='a string evaluation result')
+    boolval:  Optional[bool]  = Field(description='a boolean evaluation result')
+
+    
 
 ###
 ##   Evaluation
@@ -54,16 +86,24 @@ class Evaluation(BaseModel):
     html_output:      Optional[str] = Field(default=None, description='The uri of the html output of the evaluation run')
     pdf_output:       Optional[str] = Field(default=None, description='The uri of the pdf output of the evaluation run')
     percent_complete: Optional[int] = Field(default=0, ge=0, le=100, description='The evaluation progress as an integer completeness percentage.')
-
-    def update_status(status:           EvalStatus,
-                      percent_complete: int = 0):
-        model = EvaluationPatchRequest(**locals())
-        rsp = session.patch(f'/teams/{self.team_id}/boards/{self.board_id}/evaluations/{self.id}', model=model)
-        for key, value in rsp.json().dict():
-            setattr(self, key, value)
-
     
-
+    def results(self) -> dict:
+        """
+        return dictionary of all results for the evaluation
+        """
+        rsp = session.get(f"/teams/{self.team_id}/boards/{self.board_id}/evaluations/{self.id}/results")
+        def er2val(er):
+            if er.intval is not None:
+                return er.intval
+            if er.floatval is not None:
+                return er.floatval
+            if er.strval is not None:
+                return er.strval
+            if er.boolval is not None:
+                return er.boolval
+            return None
+        return {i['name']: er2val(EvaluationResult(**i)) for i in rsp.json()['items']}
+        
     
 ###
 ##   Artifact
@@ -322,3 +362,27 @@ def get_board(name : str,
         if board.name == name:
             return board
     
+
+
+def results(results : dict):
+    """
+    Record the final results of an evaluation run.
+    takes a dictionary of with arbitrary key names and integer, float, string, or bool values
+    """
+    team_id  = int(environ['JIGGY_TEAM_ID'])
+    board_id = int(environ['JIGGY_BOARD_ID'])
+    eval_id  = int(environ['JIGGY_EVAL_ID'])
+
+    for key, value in results.items():
+        if isinstance(value, float):
+            model = PostEvaluationResult(name=key, floatval=value)
+        elif isinstance(value, int):
+            model = PostEvaluationResult(name=key, intval=value)
+        elif isinstance(value, str):
+            model = PostEvaluationResult(name=key, strval=value)
+        elif isinstance(value, bool):
+            model = PostEvaluationResult(name=key, boolval=value)
+        else:
+            print(f"Unable to record result for {key}. (Value must be of type must be float, int, str or bool.)")
+            continue
+        session.post(f"/teams/{team_id}/boards/{board_id}/evaluations/{eval_id}/results", model=model)
