@@ -93,8 +93,8 @@ def jb_wandb_init():
                 pass
         return artifact
     
-    data_artifact = query_collection(collections,  'dataset')    
-    model_artifact = query_collection(collections, 'model')
+    data_artifact = query_collection('dataset')    
+    model_artifact = query_collection('model')
 
     print("Creating wandb artifact source and artifact watchers:")
     wandb_store = create_artifact_source(api_key=api.api_key)
